"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = appendClass;

var _utils = require("../utils");

var _propTypes = require("prop-types");

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Replace original field in uiSchema with defined configuration
 *
 * @param field
 * @param schema
 * @param uiSchema
 * @param conf
 * @returns {{schema: *, uiSchema: *}}
 */
function doAppend(field, classNames, uiSchema) {
  if (!uiSchema[field]) {
    uiSchema[field] = {};
  }
  if (uiSchema[field].classNames) {
    if (uiSchema[field].classNames.indexOf(classNames) === -1) {
      uiSchema[field].classNames = uiSchema[field].classNames + " " + classNames;
    }
  } else {
    uiSchema[field].classNames = classNames;
  }
}

function appendClass(_ref, schema, uiSchema) {
  var field = _ref.field,
      classNames = _ref.classNames;

  (0, _utils.toArray)(field).forEach(function (f) {
    return doAppend(f, classNames, uiSchema);
  });
}

if ((0, _utils.isDevelopment)()) {
  appendClass.propTypes = {
    field: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.arrayOf(_propTypes2.default.string)]).isRequired,
    classNames: _propTypes2.default.string.isRequired
  };

  appendClass.validate = (0, _utils.validateFields)("appendClass");
}